stmt

Function stmt 

pub const fn stmt(code: u16, k: u32) -> SockFilter
Build a BPF statement with one 32-bit parameter.

This is suitable for building any instruction other than conditional jumps, which have additional jump target fields.