pub const fn stmt(code: u16, k: u32) -> SockFilterExpand description
Build a BPF statement with one 32-bit parameter.
This is suitable for building any instruction other than conditional jumps, which have additional jump target fields.
pub const fn stmt(code: u16, k: u32) -> SockFilterBuild a BPF statement with one 32-bit parameter.
This is suitable for building any instruction other than conditional jumps, which have additional jump target fields.